@@ -1,10 +1,14 @@
-# Copyrights 2008-2017 by [Mark Overmeer].
+# Copyrights 2008-2020 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution XML-LibXML-Simple.  Meta-POD processed
+# with OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
 package XML::LibXML::Simple;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '1.00';
 
 use base 'Exporter';
 
@@ -26,7 +30,7 @@ use Data::Dumper;  #to be removed
 my %known_opts = map +($_ => 1),
   qw(keyattr keeproot forcecontent contentkey noattr searchpath
      forcearray grouptags nsexpand normalisespace normalizespace
-     valueattr nsstrip parser parseropts hooknodes);
+     valueattr nsstrip parser parseropts hooknodes suppressempty);
 
 my @default_attributes  = qw(name key id);
 my $default_content_key = 'content';
@@ -314,7 +318,9 @@ sub collapse($$)
         if($hooks && (my $hook = $hooks->{$child->unique_key}))
              { $v = $hook->($child) }
         else { $v = $self->collapse($child, $opts) }
-        defined $v or next CHILD;
+
+		next CHILD
+        	if ! defined $v && $opts->{suppressempty};
 
         my $name
           = $opts->{nsexpand} ? _expand_name($child)
@@ -376,6 +382,12 @@ sub collapse($$)
         && exists $data{anon}
         && ref $data{anon} eq 'ARRAY';
 
+    # Suppress empty elements?
+    if(! keys %data && exists $opts->{suppressempty}) {
+		my $sup = $opts->{suppressempty};
+        return +(defined $sup && $sup eq '') ? '' : undef;
+    }
+
     # Roll up named elements with named nested 'value' attributes
     if(my $va = $opts->{valueattrlist})
     {   while(my($key, $val) = each %data)
